import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

//redering svg tag from html
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

//Creating Line graph
const render = data => { 
  //Declaring constants we are using
  const title = 'Car company sales(2000-2015)';
  
  const xValue = d => d.SalesYear; //display dates on x axis
  const xAxisLabel = 'salesYear';

  const yValue = d => d.CarSales; //display salees value on y axis
  const yAxisLabel = 'carSales';
  
  const margin = { top: 115, right: 35, bottom: 90, left: 120 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  
  //center g in svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  // Create X scale with year values
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  //creating xAxis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(12);
  
  // Create Y scale with sales values
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  //creating yAxis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //Appending Y axis label to svg
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -82)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'blue')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  //Appending X axis label to svg
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 60)
      .attr('x', innerWidth /2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //Creating line graphs between x and y axis
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  //Appending line graph to svg
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
  //Appending title of graph to svg
  g.append('text')
      .attr('class', 'title')
      .attr('y', -15)
      .text(title);
};
//Loading data from URI
csv('https://gist.githubusercontent.com/premsaiv/21fd9b5e1aca76fbdcdc20d7f8c2f94e/raw/c34808cf447f1dc09fd6e856d83ac20a8d010b5d/cars2.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.Sales = +d.CarSales;
      d.Year = new Date(d.SalesYear)
    });
    render(data);
  })